==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/SCREENDATASPYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour SCREENDATASPYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SCREENDATASPYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DDSPYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONTABID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SCREENDATASPYID_Type", propOrder = {
    "ddspyid",
    "gridid",
    "functiontabid"
})
public class SCREENDATASPYID_Type {

    @XmlElement(name = "DDSPYID", required = true)
    protected QUANTITY ddspyid;
    @XmlElement(name = "GRIDID")
    protected Long gridid;
    @XmlElement(name = "FUNCTIONTABID")
    protected FUNCTIONTABID_Type functiontabid;

    /**
     * Obtient la valeur de la propriété ddspyid.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDDSPYID() {
        return ddspyid;
    }

    /**
     * Définit la valeur de la propriété ddspyid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDDSPYID(QUANTITY value) {
        this.ddspyid = value;
    }

    /**
     * Obtient la valeur de la propriété gridid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getGRIDID() {
        return gridid;
    }

    /**
     * Définit la valeur de la propriété gridid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setGRIDID(Long value) {
        this.gridid = value;
    }

    /**
     * Obtient la valeur de la propriété functiontabid.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public FUNCTIONTABID_Type getFUNCTIONTABID() {
        return functiontabid;
    }

    /**
     * Définit la valeur de la propriété functiontabid.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public void setFUNCTIONTABID(FUNCTIONTABID_Type value) {
        this.functiontabid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/SCREENDATASPYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for SCREENDATASPYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SCREENDATASPYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DDSPYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONTABID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SCREENDATASPYID_Type", propOrder = {
    "ddspyid",
    "gridid",
    "functiontabid"
})
public class SCREENDATASPYID_Type {

    @XmlElement(name = "DDSPYID", required = true)
    protected QUANTITY ddspyid;
    @XmlElement(name = "GRIDID")
    protected Long gridid;
    @XmlElement(name = "FUNCTIONTABID")
    protected FUNCTIONTABID_Type functiontabid;

    /**
     * Gets the value of the ddspyid property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDDSPYID() {
        return ddspyid;
    }

    /**
     * Sets the value of the ddspyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDDSPYID(QUANTITY value) {
        this.ddspyid = value;
    }

    /**
     * Gets the value of the gridid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getGRIDID() {
        return gridid;
    }

    /**
     * Sets the value of the gridid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setGRIDID(Long value) {
        this.gridid = value;
    }

    /**
     * Gets the value of the functiontabid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public FUNCTIONTABID_Type getFUNCTIONTABID() {
        return functiontabid;
    }

    /**
     * Sets the value of the functiontabid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public void setFUNCTIONTABID(FUNCTIONTABID_Type value) {
        this.functiontabid = value;
    }

}
